@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.07';
+our $VERSION = '0.0701';
 
 use Moo;
 use strictures 2;
@@ -53,10 +53,11 @@ has nrc_scores => (
 sub analyze {
     my ($self) = @_;
 
-    my $contents = $self->file ? read_text( $self->file ) : $self->text;
+    unless ( @{ $self->sentences } ) {
+        my $contents = $self->file ? read_text( $self->file ) : $self->text;
 
-    $self->sentences( get_sentences($contents) )
-        unless @{ $self->sentences };
+        $self->sentences( get_sentences($contents) );
+    }
 
     my @sentences = map { $_ } @{ $self->sentences };
 
@@ -106,10 +107,11 @@ sub nrc_sentiment {
 
     my $null_state = { anger=>0, anticipation=>0, disgust=>0, fear=>0, joy=>0, negative=>0, positive=>0, sadness=>0, surprise=>0, trust=>0 };
 
-    my $contents = $self->file ? read_text( $self->file ) : $self->text;
+    unless ( @{ $self->sentences } ) {
+        my $contents = $self->file ? read_text( $self->file ) : $self->text;
 
-    $self->sentences( get_sentences($contents) )
-        unless @{ $self->sentences };
+        $self->sentences( get_sentences($contents) );
+    }
 
     my @sentences = map { $_ } @{ $self->sentences };
 
@@ -181,7 +183,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.07
+version 0.0701
 
 =head1 SYNOPSIS
 
@@ -189,10 +191,12 @@ version 0.07
   my $opinion = Lingua::EN::Opinion->new( file => '/some/file.txt' );
   $opinion->analyze();
   my $score = $opinion->averaged_score(5);
+  my $sentiment = $opinion->get_word('foo');
   # OR
   $opinion = Lingua::EN::Opinion->new( text => 'Mary had a little lamb...' );
   $opinion->nrc_sentiment();
   # And now do something cool with $opinion->nrc_scores...
+  $sentiment = $opinion->nrc_get_word('foo');
 
 =head1 DESCRIPTION
 
@@ -257,6 +261,8 @@ in the analyzed score.
 
 =head2 nrc_sentiment()
 
+  $opinion->nrc_sentiment();
+
 Compute the NRC sentiment of the given text by sentences.
 
 This is given by a 0/1 list of these 10 emotional elements:
